@@ -448,6 +448,9 @@ class Resource(API, Operations):
                     if int(response.get("code")) == 0:
                         response["completed"] = True
 
+                    if ipn_data.get("type", -1) == super().MISYS:
+                        response["account_reference"] = f'{ipn_data.get("transaction", {}).get("reference", "").strip()}'
+
             elif ipn_data.get("bank_id", -1) == super().COOP:
 
                 response.update({
